@@ -29,6 +29,7 @@ my @core_colls = qw/
   latex
   latexrecommended
   luatex
+  mathextra
   metapost
   xetex
   /;
@@ -156,14 +157,8 @@ sub archpackages {
     }
 
     foreach my $coll (@other_colls) {
-        my $tlpcoll;
-        if ($coll eq "science") {
-            $tlpcoll = $self->get_package("collection-mathscience")
-                or croak "Can't get object for collection-mathscience";
-        } else {
-            $tlpcoll = $self->get_package("collection-$coll")
-                or croak "Can't get object for collection-$coll";
-        }
+        my $tlpcoll = $self->get_package("collection-$coll")
+            or croak "Can't get object for collection-$coll";
         foreach my $d ( $tlpcoll->depends ) {
             my $tlpdep = $self->get_package($d);
             next if ( $coll =~ /^fontsextra/ and $d =~ /^(aleph|ocherokee|oinuit)$/ );
